package
Version:
v0.0.0-...-9ebc2d1
Opens a new window with list of versions in this module.
Published: May 26, 2024
License: BSD-3-Clause
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type SearchRequest struct {
Pattern string `json:"pattern"`
Limit int `json:"limit"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.