package
Version:
v0.0.0-...-9ebc2d1
Opens a new window with list of versions in this module.
Published: May 26, 2024
License: BSD-3-Clause
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type PageEdit struct {
EditId int64 `json:"editId"`
PageId int64 `json:"pageId"`
Date string `json:"changeDate"`
Time string `json:"changeTime"`
Editor string `json:"editor"`
Description string `json:"description"`
Content string `json:"content"`
}
type SessionData struct {
LoggedIn bool
Username string
}
type StaticPage struct {
Theme string
}
type WebModes struct {
PageMode string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.